(caveats)=
# Caveats

[![Image](https://github.com/user-attachments/assets/6e8ea47c-20fd-4d37-9245-76e6cb7306ae){w=480px}][BuzzFeed]

_It's like the government is being run by BuzzFeed. [It's ridiculous!][BuzzFeed]._

## Development

It is **not recommended** that development of Rapporto takes place on a GitHub
organization account which includes private repositories. Its test suite,
invoked by CI/GHA workflow jobs, together with a misconfiguration of API
secrets, may reveal sensitive or confidential information.

## Guardrails

Rapporto provides detailed information on your fingertips which is suitable
to haunt humans, by harassing them on any of the items emitted by this program,
in one way or another. Don't do that.

> In addition to, not invalidating the existing sections in Rapporto's
> [license document], and with a strong emphasis like on topics about
> Disclaimer of Warranties and Limitation of Liabilities, THIS SOFTWARE
> MUST NOT BE USED TO JUDGE, RANK, OR TRACK PEOPLE, OR TO CREATE ANY
> KINDS OF DOSSIERS ABOUT THEM, WHERE SUCH METRICS OR RANKINGS CAN
> BE DERIVED FROM, WHICH COULD BE USED BY OTHERS FOR SIMILAR PURPOSES,
> INCLUDING MACHINES.

## Panic

![Image](https://github.com/user-attachments/assets/bb775ff8-95dd-47f9-a593-37a04757e4d8)

## People

![Image](https://github.com/user-attachments/assets/2e5321b7-839a-43b4-ba15-4b8efec91029){w=480px}

People are not standardized.
<br>
-- [People: The API User’s Guide]

## Q & A

:::{dropdown} What's the difference between a controller and a terrorist?
A terrorist at least has sympathisers.
:::

## Shrink

![Image](https://github.com/user-attachments/assets/f3618e37-3053-445b-92e2-858c0a648c41){w=480px}


[Bless America]: https://nedbatchelder.com/blog/202411/my_politics.html
[BuzzFeed]: https://youtu.be/4xGUlG5Ck6c?t=105
[license document]: https://github.com/tech-writing/rapporto/blob/main/LICENSE
[People: The API User’s Guide]: https://nedbatchelder.com/text/key23.html
[Pissed off]: https://youtu.be/zc_WOlqiLhM?t=35
